pub struct CompressedPageHeader {
pub magic: u8,
pub compression_type: u8,
pub original_size: u32,
pub compressed_size: u32,
pub compression_level: u8,
pub reserved: u8,
}Expand description
Compressed page header stored at the beginning of compressed pages This is stored within the page data on disk
Fields
magic: u8Magic byte to identify compressed pages (0xC0 = “CO” for compressed)
compression_type: u8Compression type (0=none, 1=lz4, 2=zstd)
original_size: u32Original uncompressed size (u32 to support up to 4GB pages)
compressed_size: u32Compressed data size (excluding this header)
compression_level: u8ZSTD compression level (only meaningful for ZSTD)
reserved: u8Reserved for future use
Implementations
Sourceimpl CompressedPageHeader
impl CompressedPageHeader
Sourcepub fn new(
compression_type: CompressionType,
original_size: usize,
compressed_size: usize,
) -> Self
pub fn new( compression_type: CompressionType, original_size: usize, compressed_size: usize, ) -> Self
Create a new compressed page header
Sourcepub fn from_bytes(data: &[u8]) -> Option<Self>
pub fn from_bytes(data: &[u8]) -> Option<Self>
Deserialize header from bytes
Sourcepub fn get_compression_type(&self) -> CompressionType
pub fn get_compression_type(&self) -> CompressionType
Get the compression type enum