pub struct ClockEviction { /* private fields */ }Expand description
Clock eviction policy (second-chance algorithm)
Simple and efficient. Each page has a reference bit that is set on access. The clock hand sweeps through pages, evicting the first page with reference bit = 0, and clearing reference bits as it goes.
Implementations
Sourceimpl ClockEviction
impl ClockEviction