pub struct Wal { /* private fields */ }Expand description
Write-Ahead Log manager with group commit support
Implementations
Sourceimpl Wal
impl Wal
Sourcepub fn open_with_config(
path: &Path,
config: WalGroupCommitConfig,
max_size: Option<u64>,
) -> Result<Self>
pub fn open_with_config( path: &Path, config: WalGroupCommitConfig, max_size: Option<u64>, ) -> Result<Self>
Open or create a WAL file with custom configuration
Sourcepub fn current_lsn(&self) -> Lsn
pub fn current_lsn(&self) -> Lsn
Get the current LSN
Sourcepub fn needs_recovery(&self) -> bool
pub fn needs_recovery(&self) -> bool
Check if WAL has records that need recovery (non-empty WAL)
Sourcepub fn sync_mode(&self) -> WalSyncMode
pub fn sync_mode(&self) -> WalSyncMode
Get the sync mode
Sourcepub fn current_size(&self) -> u64
pub fn current_size(&self) -> u64
Get current WAL file size in bytes
Sourcepub fn flush_group(&self) -> Result<Lsn>
pub fn flush_group(&self) -> Result<Lsn>
Flush the group commit buffer (for group commit mode) Returns the LSN up to which records were synced
Sourcepub fn log_begin(&mut self, txn_id: TransactionId) -> Result<Lsn>
pub fn log_begin(&mut self, txn_id: TransactionId) -> Result<Lsn>
Log a transaction begin
Sourcepub fn log_commit(
&mut self,
txn_id: TransactionId,
prev_lsn: Lsn,
) -> Result<Lsn>
pub fn log_commit( &mut self, txn_id: TransactionId, prev_lsn: Lsn, ) -> Result<Lsn>
Log a transaction commit
In GroupCommit mode, this adds the commit to the buffer and waits for the group flush to complete before returning.
Sourcepub fn log_abort(&mut self, txn_id: TransactionId, prev_lsn: Lsn) -> Result<Lsn>
pub fn log_abort(&mut self, txn_id: TransactionId, prev_lsn: Lsn) -> Result<Lsn>
Log a transaction abort
Sourcepub fn log_write(
&mut self,
txn_id: TransactionId,
prev_lsn: Lsn,
page_id: u64,
old_data: Vec<u8>,
new_data: Vec<u8>,
) -> Result<Lsn>
pub fn log_write( &mut self, txn_id: TransactionId, prev_lsn: Lsn, page_id: u64, old_data: Vec<u8>, new_data: Vec<u8>, ) -> Result<Lsn>
Log a page write
Sourcepub fn log_checkpoint(&mut self) -> Result<Lsn>
pub fn log_checkpoint(&mut self) -> Result<Lsn>
Log a checkpoint