pub struct FileManager { /* private fields */ }Expand description
Manages file I/O for the database
Implementations
Sourceimpl FileManager
impl FileManager
Sourcepub fn init_if_needed(&self, _config: &Config) -> Result<()>
pub fn init_if_needed(&self, _config: &Config) -> Result<()>
Initialize the database file if it’s new
Sourcepub fn read_page(&self, page_id: PageId) -> Result<Vec<u8>>
pub fn read_page(&self, page_id: PageId) -> Result<Vec<u8>>
Read a page from disk
The read order is: read from disk -> decrypt (if encrypted) -> decompress (if compressed)
Sourcepub fn write_page(&self, page_id: PageId, data: &[u8]) -> Result<()>
pub fn write_page(&self, page_id: PageId, data: &[u8]) -> Result<()>
Write a page to disk
The write order is: compress (if enabled) -> encrypt (if enabled) -> write to disk
Sourcepub fn total_pages(&self) -> u64
pub fn total_pages(&self) -> u64
Get the current total number of pages
Sourcepub fn write_superblock(&self) -> Result<()>
pub fn write_superblock(&self) -> Result<()>
Update superblock on disk
Sourcepub fn superblock(&self) -> Superblock
pub fn superblock(&self) -> Superblock
Get superblock
Sourcepub fn update_superblock<F>(&self, f: F) -> Result<()>where
F: FnOnce(&mut Superblock),
pub fn update_superblock<F>(&self, f: F) -> Result<()>where
F: FnOnce(&mut Superblock),
Update superblock
Sourcepub fn is_encrypted(&self) -> bool
pub fn is_encrypted(&self) -> bool
Check if encryption is enabled
Sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Check if compression is enabled
Sourcepub fn compression_stats(&self) -> &CompressionStats
pub fn compression_stats(&self) -> &CompressionStats
Get compression statistics Returns the stats from the compressor if compression is enabled, otherwise returns the empty stats.
Sourcepub fn compression_type(&self) -> Option<StorageCompressionType>
pub fn compression_type(&self) -> Option<StorageCompressionType>
Get the compression type (if any)
Sourcepub fn current_size(&self) -> u64
pub fn current_size(&self) -> u64
Get current database file size in bytes
Sourcepub fn remaining_capacity(&self) -> Option<u64>
pub fn remaining_capacity(&self) -> Option<u64>
Get remaining capacity before hitting limit (None if unlimited)
Sourcepub fn would_exceed_limit(&self, additional_bytes: u64) -> bool
pub fn would_exceed_limit(&self, additional_bytes: u64) -> bool
Check if an operation of given size would exceed the limit
Sourcepub fn check_disk_space(&self, _required_bytes: u64) -> Result<()>
pub fn check_disk_space(&self, _required_bytes: u64) -> Result<()>
Check if sufficient disk space is available for an operation
Returns Ok(()) if enough space, or Err(InsufficientDiskSpace) if not. This performs a best-effort check. On platforms where we can’t determine available space, we optimistically allow the operation (it will fail with I/O error if there’s actually insufficient space).